@@ -5,9 +5,9 @@
 /*
  * function prototype
  */
-void diehard_craps(Test **test,int irun);
+int diehard_craps(Test **test,int irun);
 
-static Dtest diehard_craps_dtest = {
+static Dtest diehard_craps_dtest __attribute__((unused)) = {
   "Diehard Craps Test",
   "diehard_craps",
   "\
@@ -26,6 +26,8 @@ static Dtest diehard_craps_dtest = {
 #==================================================================\n",
   100,     /* Default psamples */
   200000,  /* Default tsamples */
-  2        /* This test returns two statistics */
+  2,       /* This test returns two statistics */
+  diehard_craps,
+  0
 };
 
