@@ -1,8 +1,5 @@
 /*
- * $Id: diehard_squeeze.c 231 2006-08-22 16:18:05Z rgb $
- *
  * See copyright in copyright.h and the accompanying file COPYING
- *
  */
 
 /*
@@ -42,7 +39,19 @@
 
 #include <dieharder/libdieharder.h>
 
-void diehard_squeeze(Test **test, int irun)
+static double sdata[]={
+0.00002103, 0.00005779, 0.00017554, 0.00046732, 0.00110783,
+0.00236784, 0.00460944, 0.00824116, 0.01362781, 0.02096849,
+0.03017612, 0.04080197, 0.05204203, 0.06283828, 0.07205637,
+0.07869451, 0.08206755, 0.08191935, 0.07844008, 0.07219412,
+0.06398679, 0.05470931, 0.04519852, 0.03613661, 0.02800028,
+0.02105567, 0.01538652, 0.01094020, 0.00757796, 0.00511956,
+0.00337726, 0.00217787, 0.00137439, 0.00084970, 0.00051518,
+0.00030666, 0.00017939, 0.00010324, 0.00005851, 0.00003269,
+0.00001803, 0.00000982, 0.00001121
+};
+
+int diehard_squeeze(Test **test, int irun)
 {
 
  int i,j,k;
@@ -56,11 +65,16 @@ void diehard_squeeze(Test **test, int irun)
   * on the vector (Vtest) then yields a pvalue for the test run.
   */
 
+ /*
+  * for display only.  0 means "ignored".
+  */
+ test[0]->ntuple = 0;
+
  /*
   * Allocate memory for Vtest struct vector (length 51) and initialize
   * it with the expected values.
   */
- Vtest_create(&vtest,43,"diehard_squeeze",gsl_rng_name(rng));
+ Vtest_create(&vtest,43);
  /*
   * Initialize the expected value vector
   */
@@ -114,5 +128,9 @@ void diehard_squeeze(Test **test, int irun)
    printf("# diehard_squeeze(): test[0]->pvalues[%u] = %10.5f\n",irun,test[0]->pvalues[irun]);
  }
 
+ Vtest_destroy(&vtest);
+
+ return(0);
+
 }
 
